Re:“Clean” Code, Horrible Performance
by loup-vaillant on Wednesday March 01, 2023 @02:58AM
(#34979856)
I tried auto-vectorisation, and it worked pretty well. But the code became just as big as using intrinsics would have (that with explicitly unrolling loops and rearranging things in memory), and intrinsics generated code that was easily 35% faster.
I decided not put it off for later, and keep things simple for now.
I decided not put it off for later, and keep things simple for now.